@@ -14,6 +14,9 @@ class thunderbird_labels extends rcube_plugin
 	private $rc;
 	private $map;
 	private $_custom_flags_allowed = null;
+	private $name;
+	private $add_tb_flags;
+	private $message_tb_labels;
 	const LABEL_STYLES = ['thunderbird', 'bullets', 'badges'];
 
 	function init()
@@ -435,7 +438,7 @@ class thunderbird_labels extends rcube_plugin
 			$data = $RCMAIL->storage->folder_data($mbox_name);
 
 			if (empty($_SESSION['list_mod_seq']) || $_SESSION['list_mod_seq'] != $data['HIGHESTMODSEQ']) {
-			   $flags = $RCMAIL->storage->list_flags($mbox_name, explode(',', $uids), $_SESSION['list_mod_seq']);
+			   $flags = $RCMAIL->storage->list_flags($mbox_name, explode(',', $uids), !empty($_SESSION['list_mod_seq'])? $_SESSION['list_mod_seq'] : null);
 			   foreach ($flags as $idx => $row) {
 				   $flags[$idx] = array_change_key_case(array_map('intval', $row));
 			   }
